@@ -162,6 +162,11 @@ class ExperimentCompiler(Compiler):
         df[df == 0] = np.nan
         return df
 
+    def compile_growth_metrics(
+        self, metrics=["max_dVol", "max_bud_dVol", "nbirths", "cycle_length"]
+    ):
+        pass
+
     def compile_ncells(self):
         df = self.count_cells()
         df = df.melt(ignore_index=False)
@@ -389,7 +394,6 @@ class PageOrganiser(object):
         if grid_spec is None:
             grid_spec = (1, 1)
         title_fontsize = "x-small"
-        # self.fig = plt.figure(dpi=300, tight_layout=True)
         self.fig = plt.figure(dpi=300)
         self.fig.set_size_inches(8.27, 11.69, forward=True)
         plt.figtext(0.02, 0.99, "", fontsize="small")
